;; Generated package description from verilog-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "verilog-mode" "2026.4.14.10117132.0.20260816.1" "major mode for editing verilog source in Emacs" 'nil :commit "88cb65aae52e6a6c7adb82d067c8a20189393f61" :authors '(("Michael McNamara" . "mac@verilog.com") ("Wilson Snyder" . "wsnyder@wsnyder.org")) :maintainer '(("Michael McNamara" . "mac@verilog.com") ("Wilson Snyder" . "wsnyder@wsnyder.org")) :keywords '("languages") :url "https://www.veripool.org")
